@@ -356,7 +356,8 @@ class Company(models.Model):
     :country: The country, this company is in.
     :code: A short identifier for this company.
     :description: Full company description (name).
-    :shipping_days: How many shipping days this company needs.
+    :shipping_days: How many shipping days it needs to ship from or to this
+      company
 
     reverse relations:
     :cboms: All the CBOMs related to this company.
