@@ -6,21 +6,7 @@ from django.conf import settings
 from django.test import TestCase
 
 from ..models import BOM, BOMItem
-from .factories import (
-    AdditionalTextFactory,
-    BOMFactory,
-    BOMItemFactory,
-    CBOMFactory,
-    CBOMItemFactory,
-    CompanyFactory,
-    CountryFactory,
-    EPNFactory,
-    IPNFactory,
-    PriceGroupFactory,
-    PriceMarkerFactory,
-    ShapeFactory,
-    UnitFactory,
-)
+from . import factories
 
 
 class AdditionalTextTestCase(TestCase):
@@ -29,7 +15,7 @@ class AdditionalTextTestCase(TestCase):
 
     def test_instantiation(self):
         """Test instantiation of the ``AdditionalText`` model."""
-        additionaltext = AdditionalTextFactory()
+        additionaltext = factories.AdditionalTextFactory()
         self.assertTrue(additionaltext.pk)
 
 
@@ -39,7 +25,7 @@ class BOMTestCase(TestCase):
 
     def test_instantiation(self):
         """Test instantiation of the ``BOM`` model."""
-        bom = BOMFactory()
+        bom = factories.BOMFactory()
         self.assertTrue(bom.pk)
 
 
@@ -49,7 +35,7 @@ class BOMItemTestCase(TestCase):
 
     def test_instantiation(self):
         """Test instantiation of the ``BOMItem`` model."""
-        bomitem = BOMItemFactory()
+        bomitem = factories.BOMItemFactory()
         self.assertTrue(bomitem.pk)
 
 
@@ -58,14 +44,14 @@ class CBOMTestCase(TestCase):
     longMessage = True
 
     def setUp(self):
-        self.cbom = CBOMFactory()
+        self.cbom = factories.CBOMFactory()
 
     def test_instantiation(self):
         """Test instantiation of the ``CBOM`` model."""
         self.assertTrue(self.cbom.pk)
 
     def test_get_bom(self):
-        self.cbomitem = CBOMItemFactory(bom=self.cbom, consign=False)
+        self.cbomitem = factories.CBOMItemFactory(bom=self.cbom, consign=False)
         self.assertEqual(
             self.cbom.get_bom(),
             BOM(description=self.cbom.description, ipn=None))
@@ -73,12 +59,12 @@ class CBOMTestCase(TestCase):
     def test_get_bom_csv_file(self):
         path = os.path.join(settings.MEDIA_URL, 'BOM_{0}.csv'.format(
             self.cbom.id))
-        self.cbomitem = CBOMItemFactory(bom=self.cbom, consign=False)
+        self.cbomitem = factories.CBOMItemFactory(bom=self.cbom, consign=False)
         self.assertEqual(self.cbom.get_bom_csv_file(), path)
 
     def test_get_bom_items(self):
-        self.cbomitem = CBOMItemFactory(bom=self.cbom, consign=False)
-        CBOMItemFactory(bom=self.cbom, consign=True)
+        self.cbomitem = factories.CBOMItemFactory(bom=self.cbom, consign=False)
+        factories.CBOMItemFactory(bom=self.cbom, consign=True)
         self.assertEqual(
                 self.cbom.get_bom_items()[0],
                 BOMItem(ipn=self.cbomitem.epn.ipn,
@@ -88,7 +74,7 @@ class CBOMTestCase(TestCase):
     def test_get_csv_file(self):
         path = os.path.join(settings.MEDIA_URL, 'cBOM_{0}.csv'.format(
             self.cbom.id))
-        self.cbomitem = CBOMItemFactory(bom=self.cbom, consign=False)
+        self.cbomitem = factories.CBOMItemFactory(bom=self.cbom, consign=False)
         self.assertEqual(self.cbom.get_csv_file(), path)
 
 
@@ -98,7 +84,7 @@ class CBOMItemTestCase(TestCase):
 
     def test_instantiation(self):
         """Test instantiation of the ``CBOMItem`` model."""
-        cbomitem = CBOMItemFactory()
+        cbomitem = factories.CBOMItemFactory()
         self.assertTrue(cbomitem.pk)
 
 
@@ -108,7 +94,7 @@ class CompanyTestCase(TestCase):
 
     def test_instantiation(self):
         """Test instantiation of the ``Company`` model."""
-        company = CompanyFactory()
+        company = factories.CompanyFactory()
         self.assertTrue(company.pk)
 
 
@@ -118,7 +104,7 @@ class CountryTestCase(TestCase):
 
     def test_instantiation(self):
         """Test instantiation of the ``Country`` model."""
-        country = CountryFactory()
+        country = factories.CountryFactory()
         self.assertTrue(country.pk)
 
 
@@ -128,7 +114,7 @@ class EPNTestCase(TestCase):
 
     def test_instantiation(self):
         """Test instantiation of the ``EPN`` model."""
-        epn = EPNFactory()
+        epn = factories.EPNFactory()
         self.assertTrue(epn.pk)
 
 
@@ -138,15 +124,15 @@ class IPNTestCase(TestCase):
 
     def test_instantiation(self):
         """Test instantiation of the ``IPN`` model."""
-        ipn = IPNFactory()
+        ipn = factories.IPNFactory()
         self.assertTrue(ipn.pk)
 
     def test_price_max(self):
         """Test for the ``price_max`` property."""
-        ipn = IPNFactory()
+        ipn = factories.IPNFactory()
         self.assertIsNone(ipn.price_max, msg=(
             'Without a PriceMarker, the price_max should be None.'))
-        PriceMarkerFactory(ipn=ipn)
+        factories.PriceMarkerFactory(ipn=ipn)
         self.assertEqual(ipn.price_max, Decimal('54.32100000'), msg=(
             'The price max was not calculated correctly.'))
 
@@ -157,7 +143,7 @@ class PriceGroupTestCase(TestCase):
 
     def test_instantiation(self):
         """Test instantiation of the ``PriceGroup`` model."""
-        pricegroup = PriceGroupFactory()
+        pricegroup = factories.PriceGroupFactory()
         self.assertTrue(pricegroup.pk)
 
 
@@ -167,7 +153,7 @@ class PriceMarkerTestCase(TestCase):
 
     def test_instantiation(self):
         """Test instantiation of the ``PriceMarker`` model."""
-        pricemarker = PriceMarkerFactory()
+        pricemarker = factories.PriceMarkerFactory()
         self.assertTrue(pricemarker.pk)
 
 
@@ -177,15 +163,24 @@ class ShapeTestCase(TestCase):
 
     def test_instantiation(self):
         """Test instantiation of the ``Shape`` model."""
-        shape = ShapeFactory()
+        shape = factories.ShapeFactory()
         self.assertTrue(shape.pk)
 
 
+class TechnologyTestCase(TestCase):
+    """Tests for the ``Technology`` model class."""
+    longMessage = True
+
+    def test_instantiation(self):
+        technology = factories.TechnologyFactory()
+        self.assertTrue(technology.pk)
+
+
 class UnitTestCase(TestCase):
     """Tests for the ``Unit`` model class."""
     longMessage = True
 
     def test_instantiation(self):
         """Test instantiation of the ``Unit`` model."""
-        unit = UnitFactory()
+        unit = factories.UnitFactory()
         self.assertTrue(unit.pk)
