@@ -1,6 +1,11 @@
 """Settings that need to be set in order to run the tests."""
 import os
 
+import logging
+
+logger = logging.getLogger('factory')
+logger.setLevel(logging.INFO)
+
 DEBUG = True
 
 SITE_ID = 1
@@ -48,7 +53,6 @@ EXTERNAL_APPS = [
     'django.contrib.staticfiles',
     'django.contrib.sitemaps',
     'django.contrib.sites',
-    'django_jasmine',
     'django_nose',
     'django_libs',
 ]
@@ -62,3 +66,7 @@ INSTALLED_APPS = EXTERNAL_APPS + INTERNAL_APPS
 COVERAGE_MODULE_EXCLUDES += EXTERNAL_APPS
 
 SECRET_KEY = 'foobar'
+
+FILE_UPLOAD_HANDLERS = (
+    "django.core.files.uploadhandler.TemporaryFileUploadHandler",
+)
